@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -32,7 +32,7 @@ public:
     explicit GravatarDownloadPixmapDialog(QWidget *parent = nullptr);
     ~GravatarDownloadPixmapDialog();
 
-    QPixmap gravatarPixmap() const;
+    Q_REQUIRED_RESULT QPixmap gravatarPixmap() const;
 
 private:
     void slotAccepted();
